import socket
import logging
import traceback
from django.conf import settings
from bernhard import Client, UDPTransport, TCPTransport

RIEMANN_HOST = getattr(settings, 'RIEMANN_LOGGER_HOST', '127.0.0.1')
RIEMANN_PORT = getattr(settings, 'RIEMANN_LOGGER_PORT', '5555')
RIEMANN_TRANSPORT = getattr(settings, 'RIEMANN_LOGGER_TRANSPORT', 'udp')
HOST = socket.gethostname()

if RIEMANN_TRANSPORT == 'udp':
    transport = UDPTransport
elif RIEMANN_TRANSPORT == 'tcp':
    transport = TCPTransport
else:
    raise Exception("'%s' transport unknown" % RIEMANN_TRANSPORT)

c = Client(host=RIEMANN_HOST, port=RIEMANN_PORT, transport=transport)


class RiemannHandler(logging.Handler, object):

    def emit(self, record):
        event = {
            'host': HOST,
            'service': 'django-logger',
            'state': record.levelname,
            'time': int(record.created),
            'tags': [record.name]
        }

        if record.exc_info:
            tb = traceback.format_exception(*record.exc_info)
            event['description'] = ''.join(tb)

        c.send(event)




from setuptools import setup

try:
    long_desc = open('README.md').read()
except IOError:
    long_desc = ''

setup(
    name='django-riemann',
    version='0.0.2',
    url='https://github.com/honza/django-riemann',
    install_requires=[
        'bernhard'
    ],
    description='Send logging data to Riemann',
    long_description=long_desc,
    author='Honza Pokorny',
    author_email='me@honza.ca',
    maintainer='Honza Pokorny',
    maintainer_email='me@honza.ca',
    packages=['riemann'],
    include_package_data=True
)
